[−][src]Enum ffsend_api::action::download::DownloadError
Variants
An error occurred while computing the cryptographic signature used for downloading the file.
Sending the request to download the file failed.
Response(ResponseError)The server responded with an error while requesting the file download.
Failed to start or update the downloading progress, because of this the download can't continue.
The actual download and decryption process the server. This covers reading the file from the server, decrypting the file, and writing it to the file system.