[−][src]Enum ffsend_api::action::download::FileError
Variants
Create(IoError)An error occurred while creating or opening the file to write to.
Failed to create an encrypted writer for the file, which is used to decrypt the downloaded file.