Struct ffsend_api::action::download::Download[][src]

pub struct Download<'a> { /* fields omitted */ }

A file upload action to a Send server.

Methods

impl<'a> Download<'a>
[src]

Construct a new download action for the given remote file. It is recommended to check whether the file exists, unless that is already done.

Invoke the download action.