pub struct Exists<'a> { /* private fields */ }
An action to check whether a remote file exists. This aciton returns an ExistsResponse, that defines whether the file exists, and whether it is protected by a password.

Implementations

Construct a new exists action.

Invoke the exists action.