Module ffsend_api::action::info

source ·

Structs

An action to fetch info of a shared file.
The info data object. This object is currently empty, as no additional data is sent to the server.
The file info response.

Enums