[][src]Enum ffsend_api::action::info::Error

pub enum Error {
    Prepare(PrepareError),
    Expired,
    Info(InfoError),
}

Variants

Prepare(PrepareError)

An error occurred while preparing the action.

Expired

The given Send file has expired, or did never exist in the first place. Therefore the file could not be downloaded.

Info(InfoError)

An error has occurred while sending the info request to the server.