[−][src]Enum ffsend_api::action::info::InfoDataError
Variants
Owned(DataError)Some error occurred while trying to wrap the info data in an owned object, which is required for authentication on the server. The wrapped error further described the problem.