[−][src]Enum ffsend_api::action::info::InfoError
Variants
Sending the request to fetch the file info failed.
Response(ResponseError)The server responded with an error while fetching the file info.
Decode(ReqwestError)Failed to decode the info response from the server. Maybe the server responded with data from a newer API version.