Struct ffsend_api::action::info::Info

source ·
pub struct Info<'a> { /* private fields */ }
An action to fetch info of a shared file.

Implementations

Construct a new info action for the given remote file.

Invoke the info action.