pub struct InfoResponse { /* private fields */ }
The file info response.

Implementations

Get the number of times this file has been downloaded.

Get the maximum number of times the file may be downloaded.

Get the number of times this file may still be downloaded.

Get the time to live for this file, in milliseconds from the time the request was made.