Module ffsend_api::action::metadata

source ·

Structs

An action to fetch file metadata.
The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.
The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted.

Enums