[][src]Enum ffsend_api::action::metadata::Error

pub enum Error {
    Exists(ExistsError),
    Request(RequestError),
    Expired,
    PasswordRequired,
}

Variants

Exists(ExistsError)

An error occurred while checking whether the file exists on the server.

Request(RequestError)

A general error occurred while requesting the file data. This may be because authentication failed, because decrypting the file metadata didn't succeed, or due to some other reason.

Expired

The given Send file has expired, or did never exist in the first place. Therefore the file could not be downloaded.

PasswordRequired

A password is required, but was not given.