[−][src]Enum ffsend_api::action::metadata::RawMetadataResponse
The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted.
Variants
Raw metadata using in Send v2.
Raw metadata using in Send v3.
Fields of V3
meta: StringThe encrypted metadata.
Implementations
impl RawMetadataResponse[src]
pub fn decrypt_metadata(
&self,
key_set: &KeySet
) -> Result<MetadataData, MetadataError>[src]
&self,
key_set: &KeySet
) -> Result<MetadataData, MetadataError>
Get and decrypt the metadata, based on the raw data in this response.
The decrypted data is verified using an included tag. If verification failed, an error is returned.
pub fn size(&self) -> Option<u64>[src]
Get the file size in bytes, if provided by the server (= Send v2).