pub struct MetadataResponse { /* private fields */ }
The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.

Implementations

Construct a new response with the given metadata and nonce.

Get the metadata.

Get the file size in bytes.

Get the nonce.