pub struct RawMetadataResponse { /* private fields */ }
The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted.

Implementations

Get and decrypt the metadata, based on the raw data in this response.

The decrypted data is verified using an included tag. If verification failed, an error is returned.

Get the file size in bytes.