[][src]Enum ffsend_api::action::params::ParamsDataError

pub enum ParamsDataError {
    DownloadBounds,
    Owned(DataError),
}

Variants

DownloadBounds

The number of downloads is invalid, as it was out of the allowed bounds. See PARAMS_DOWNLOAD_MIN and PARAMS_DOWNLOAD_MAX.

Owned(DataError)

Some error occurred while trying to wrap the parameter data in an owned object, which is required for authentication on the server. The wrapped error further described the problem.