Struct ffsend_api::action::params::Params [−][src]
pub struct Params<'a> { /* fields omitted */ }An action to set parameters for a shared file.
Methods
impl<'a> Params<'a>[src]
impl<'a> Params<'a>pub fn new(
file: &'a RemoteFile,
params: ParamsData,
nonce: Option<Vec<u8>>
) -> Self[src]
pub fn new(
file: &'a RemoteFile,
params: ParamsData,
nonce: Option<Vec<u8>>
) -> SelfConstruct a new parameters action for the given remote file.
pub fn invoke(self, client: &Client) -> Result<(), Error>[src]
pub fn invoke(self, client: &Client) -> Result<(), Error>Invoke the parameters action.