[−][src]Struct ffsend_api::action::params::ParamsData
The parameters data object, that is sent to the server.
Fields
download_limit: Option<u8>The number of times this file may be downloaded. This value must be within a specific range, as enforced by Send servers.
expiry_time: Option<usize>The time in seconds after when the file expires. This value must be within a specific range, as enforced by Send servers. Only used with Send v3.
Implementations
impl ParamsData[src]
pub fn new() -> Self[src]
Construct a new parameters object, that is empty.
pub fn from(download_limit: Option<u8>, expiry_time: Option<usize>) -> Self[src]
Create a new parameters data object, with the given parameters.
pub fn set_download_limit(
&mut self,
download_limit: Option<u8>
) -> Result<(), ParamsDataError>[src]
&mut self,
download_limit: Option<u8>
) -> Result<(), ParamsDataError>
Set the maximum number of allowed downloads, after which the file will be removed.
None may be given, to keep this parameter as is.
An error may be returned if the download value is out of the allowed
bound. These bounds are fixed and enforced by the server.
See PARAMS_DOWNLOAD_MIN and PARAMS_DOWNLOAD_MAX.
pub fn set_expiry_time(
&mut self,
expiry_time: Option<usize>
) -> Result<(), ParamsDataError>[src]
&mut self,
expiry_time: Option<usize>
) -> Result<(), ParamsDataError>
Set the expiry time in seconds for files.
None may be given, to keep this parameter as is.
An error may be returned if the expiry time value is out of the allowed bound. These bounds are fixed and enforced by the server.
pub fn is_empty(&self) -> bool[src]
Check whether this parameters object is empty, and wouldn't change any parameter on the server when sent. Sending an empty parameter data object would thus be useless.
pub fn normalize(&mut self, version: Version)[src]
Normalize this data for the given version.
For example, Send v2 does not support the expiry time field. If normalizing for this version this field is dropped from the struct.