Struct ffsend_api::action::password::Password[][src]

pub struct Password<'a> { /* fields omitted */ }

An action to change a password of an uploaded Send file.

Methods

impl<'a> Password<'a>
[src]

Construct a new password action for the given remote file.

Invoke the password action.