Enum ffsend_api::action::upload::FileError[][src]

pub enum FileError {
    NotAFile,
    Open(IoError),
}

Variants

The given path, is not not a file or doesn't exist.

Failed to open the file that must be uploaded for reading.