[][src]Enum ffsend_api::action::upload::PrepareError

pub enum PrepareError {
    Meta(MetadataError),
    Reader(ReaderError),
    Client,
}

Variants

Meta(MetadataError)

Failed to prepare the file metadata for uploading.

Reader(ReaderError)

Failed to create an encrypted file reader, that encrypts the file on the fly when it is read.

Client

Failed to create a client for uploading a file.