[−][src]Enum ffsend_api::action::upload::UploadError
Variants
Failed to start or update the uploading progress, because of this the upload can't continue.
Sending the request to upload the file failed.
An error occurred while streaming the encrypted file (including file info, header and footer) for uploading over a websocket.
The server responded with data that was not understood, or did not respond at all while a response was espected.
Response(ResponseError)The server responded with an error for uploading.
Decode(ReqwestError)Failed to decode the upload response from the server. Maybe the server responded with data from a newer API version.
ParseUrl(UrlParseError)Failed to parse the retrieved URL from the upload response.