[−][src]Struct ffsend_api::action::version::Version
An action to attempt to find the API version of a Send server.
This returns a Version as probed, and will return an error if failed to properly determine
the server API version.
This API specification for this action is compatible with both Firefox Send v2 and v3.
Implementations
impl Version[src]
pub fn new(host: Url) -> Self[src]
Construct a new version action.
pub fn invoke(self, client: &Client) -> Result<Version, Error>[src]
Invoke the version action.