[−][src]Enum ffsend_api::api::nonce::NonceError
Variants
Sending the request to fetch a nonce failed, as the file has expired or did never exist.
Sending the request to fetch a nonce failed.
Response(ResponseError)The server responded with an error while requesting the encryption nonce, required for some operations.
The nonce header was missing from the request.
The received nonce could not be parsed, because it was malformed. Maybe the server responded with a new format that isn't supported yet by this client.