[][src]Struct ffsend_api::client::Client

pub struct Client { /* fields omitted */ }

A networking client for ffsend actions.

Implementations

impl Client[src]

pub fn new(config: ClientConfig, transfer: bool) -> Self[src]

Construct the ffsend client with the given config.

If this client is used for transfering files, transfer should be true.

pub fn get<U: IntoUrl>(&self, url: U) -> ReqwestRequestBuilder[src]

Create a HTTP GET request through this client, returning a RequestBuilder.

pub fn post<U: IntoUrl>(&self, url: U) -> ReqwestRequestBuilder[src]

Create a HTTP GET request through this client, returning a RequestBuilder.

pub fn execute(&self, request: ReqwestRequest) -> Result<ReqwestResponse>[src]

Execute the given reqwest request through the internal reqwest client.

pub fn websocket(
    &self,
    url: &str
) -> WsResult<WsClient<Box<dyn WsNetworkStream + Send>>>
[src]

Construct a websocket client connected to the given url using the wrapped configuration.