downloads_max

Function downloads_max 

pub fn downloads_max(version: Version, _auth: bool) -> &'static [usize]
Get supported maximum number of download values for a Send file.

The remote server only accepts any of these specific values, and nothing in between.