expiry_max

Function expiry_max 

pub fn expiry_max(version: Version, _auth: bool) -> &'static [usize]
Get supported maximum file expiry time values in seconds for a Send file.

The remote server only accepts any of these specific values, and nothing in between.