Struct ffsend_api::crypto::key_set::KeySet[][src]

pub struct KeySet { /* fields omitted */ }

Methods

impl KeySet
[src]

Construct a new key, with the given secret and iv.

Create a key set from the given file ID and secret. This method may be used to create a key set based on a share URL.

Generate a secure new key.

If derive is true, file, authentication and metadata keys will be derived from the generated secret.

Derive a file, authentication and metadata key.

Derive an authentication key, with the given password and file URL. This method does not derive a (new) file and metadata key.

Important traits for &'a [u8]

Get the secret key.

Get the secret key as URL-safe base64 encoded string.

Important traits for &'a [u8]

Get the input vector.

Set the input vector.

Get the file encryption key, if derived.

Get the authentication encryption key, if derived.

Get the authentication encryption key, if derived, as URL-safe base64 encoded string.

Get the metadata encryption key, if derived.

Get the cipher type to use in combination with these keys.