Struct ffsend_api::file::metadata::XFileMetadata [−][src]
pub struct XFileMetadata { /* fields omitted */ }A X-File-Metadata header for reqwest, that is used to pass encrypted metadata to the server.
The encrypted metadata (bytes) is base64 encoded when constructing this
header using from.
Methods
impl XFileMetadata[src]
impl XFileMetadataTrait Implementations
impl Clone for XFileMetadata[src]
impl Clone for XFileMetadatafn clone(&self) -> XFileMetadata[src]
fn clone(&self) -> XFileMetadataReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Header for XFileMetadata[src]
impl Header for XFileMetadataMake this struct usable as reqwest header.
fn header_name() -> &'static str[src]
fn header_name() -> &'static strReturns the name of the header field this belongs to. Read more
fn parse_header(_raw: &Raw) -> Result<Self, HyperError>[src]
fn parse_header(_raw: &Raw) -> Result<Self, HyperError>Parse a header from a raw stream of bytes. Read more
fn fmt_header(&self, f: &mut HeaderFormatter) -> Result[src]
fn fmt_header(&self, f: &mut HeaderFormatter) -> ResultFormat a header to outgoing stream. Read more