[−][src]Struct ffsend_api::pipe::crypto::ece::EceCrypt
Something that can encrypt or decrypt given data using ECE.
Implementations
impl EceCrypt[src]
pub fn new(
mode: CryptMode,
len: usize,
ikm: Vec<u8>,
salt: Option<Vec<u8>>
) -> Self[src]
mode: CryptMode,
len: usize,
ikm: Vec<u8>,
salt: Option<Vec<u8>>
) -> Self
Construct a new ECE crypter pipe.
It is highly recommended to use the encrypt() and
decrypt() methods instead for constructing a new crypter.
The size in bytes of the plaintext data must be given as len.
The input key material must be given as ikm.
When encrypting, a salt must be specified.
pub fn encrypt(len: usize, ikm: Vec<u8>, salt: Option<Vec<u8>>) -> Self[src]
Create an ECE encryptor.
The size in bytes of the plaintext data that is encrypted decrypt must be given as len.
The input key material must be given as ikm.
The salt is optional and will be randomly generated if None.
pub fn decrypt(len: usize, ikm: Vec<u8>) -> Self[src]
Create an ECE decryptor.
The size in bytes of the plaintext data that is decrypted decrypt must be given as len.
The input key material must be given as ikm.