PipeLen

Trait PipeLen 

pub trait PipeLen {
    // Required methods
    fn len_in(&self) -> usize;
    fn len_out(&self) -> usize;
}
Defines number of bytes transformed into/out of pipe if fixed.

For example, the AES-GCM cryptography pipe adds 16 bytes to the encrypted payload for the verification tag. When transforming a file the length is known. Then, the len_out for an AES-GCM encrypter is 16 bytes larger than len_in. For a decrypter this is the other way around.

Required Methods

fn len_in(&self) -> usize

The number of bytes that are transfered into the pipe if fixed.

fn len_out(&self) -> usize

The number of bytes that are transfered out of the pipe if fixed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors