PipeRead

Trait PipeRead 

pub trait PipeRead<P>: Read
where P: Pipe,
{ // Required method fn new(pipe: P, inner: Box<dyn Read>) -> Self; }
A reader wrapping another reader, to encrypt or decrypt data read from it.

Required Methods

fn new(pipe: P, inner: Box<dyn Read>) -> Self

Wrap the given inner reader, transform data using crypt.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors