PipeWrite

Trait PipeWrite 

pub trait PipeWrite<P>: Write
where P: Pipe,
{ // Required method fn new(pipe: P, inner: Box<dyn Write>) -> Self; }
A writer wrapping another writher, to encrypt or decrypt data it is writen to.

Required Methods

fn new(pipe: P, inner: Box<dyn Write>) -> Self

Wrap the given inner writer, transform data using crypt.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors