Enum ffsend_api::action::delete::DeleteDataError[][src]

pub enum DeleteDataError {
    Owned(DataError),
}

Variants

Some error occurred while trying to wrap the deletion data in an owned object, which is required for authentication on the server. The wrapped error further described the problem.