Enum ffsend_api::action::download::DownloadError[][src]

pub enum DownloadError {
    ComputeSignature,
    Request,
    Response(ResponseError),
    NoLength,
    Progress,
    Download,
    Verify,
}

Variants

An error occurred while computing the cryptographic signature used for downloading the file.

Sending the request to download the file failed.

The server responded with an error while requesting the file download.

The length of the file is missing, thus the length of the file to download couldn't be determined.

Failed to start or update the downloading progress, because of this the download can't continue.

The actual download and decryption process the server. This covers reading the file from the server, decrypting the file, and writing it to the file system.

Verifying the downloaded file failed.