Enum ffsend_api::action::download::Error[][src]

pub enum Error {
    Meta(MetadataError),
    Expired,
    PasswordRequired,
    Download(DownloadError),
    Decrypt,
    File(StringFileError),
}

Variants

An error occurred while fetching the metadata of the file. This step is required in order to succsessfully decrypt the file that will be downloaded.

The given Send file has expired, or did never exist in the first place. Therefore the file could not be downloaded.

A password is required, but was not given.

An error occurred while downloading the file.

An error occurred while decrypting the downloaded file.

An error occurred while opening or writing to the target file.