Enum ffsend_api::action::download::Error [−][src]
pub enum Error {
Meta(MetadataError),
Expired,
PasswordRequired,
Download(DownloadError),
Decrypt,
File(String, FileError),
}Variants
Meta(MetadataError)An error occurred while fetching the metadata of the file. This step is required in order to succsessfully decrypt the file that will be downloaded.
ExpiredThe given Send file has expired, or did never exist in the first place. Therefore the file could not be downloaded.
PasswordRequiredA password is required, but was not given.
Download(DownloadError)An error occurred while downloading the file.
DecryptAn error occurred while decrypting the downloaded file.
File(String, FileError)An error occurred while opening or writing to the target file.