Struct ffsend_api::action::download::Download [−][src]
pub struct Download<'a> { /* fields omitted */ }A file upload action to a Send server.
Methods
impl<'a> Download<'a>[src]
impl<'a> Download<'a>pub fn new(
file: &'a RemoteFile,
target: PathBuf,
password: Option<String>,
check_exists: bool,
metadata_response: Option<MetadataResponse>
) -> Self[src]
pub fn new(
file: &'a RemoteFile,
target: PathBuf,
password: Option<String>,
check_exists: bool,
metadata_response: Option<MetadataResponse>
) -> SelfConstruct a new download action for the given remote file. It is recommended to check whether the file exists, unless that is already done.
pub fn invoke(
self,
client: &Client,
reporter: &Arc<Mutex<ProgressReporter>>
) -> Result<(), Error>[src]
pub fn invoke(
self,
client: &Client,
reporter: &Arc<Mutex<ProgressReporter>>
) -> Result<(), Error>Invoke the download action.