Module ffsend_api::action::exists
source · Structs
An action to check whether a remote file exists.
This aciton returns an
ExistsResponse, that defines whether the file
exists, and whether it is protected by a password.The exists response.