[−][src]Enum ffsend_api::action::exists::Error
Variants
Sending the request to check whether the file exists failed.
Response(ResponseError)The server responded with an error while checking whether the file exists.
The response from the server when checking if the file exists was malformed. Maybe the server responded with a new format that isn't supported yet by this client.