Enum ffsend_api::action::exists::Error [−][src]
pub enum Error {
Request,
Response(ResponseError),
Malformed,
}Variants
RequestSending the request to check whether the file exists failed.
Response(ResponseError)The server responded with an error while checking whether the file exists.
MalformedThe response from the server when checking if the file exists was malformed. Maybe the server responded with a new format that isn't supported yet by this client.