Enum ffsend_api::action::exists::Error[][src]

pub enum Error {
    Request,
    Response(ResponseError),
    Malformed,
}

Variants

Sending the request to check whether the file exists failed.

The server responded with an error while checking whether the file exists.

The response from the server when checking if the file exists was malformed. Maybe the server responded with a new format that isn't supported yet by this client.