Struct ffsend_api::action::exists::Exists
source · pub struct Exists<'a> { /* private fields */ }Expand description
An action to check whether a remote file exists.
This aciton returns an ExistsResponse, that defines whether the file
exists, and whether it is protected by a password.
Implementations