Struct ffsend_api::action::exists::Exists
[−]
[src]
pub struct Exists<'a> { /* fields omitted */ }An action to check whether a remote file exists.
This aciton returns an ExistsResponse, that defines whether the file
exists, and whether it is protected by a password.
Methods
impl<'a> Exists<'a>[src]
pub fn new(file: &'a RemoteFile) -> Self[src]
Construct a new exists action.
pub fn invoke(self, client: &Client) -> Result<ExistsResponse, Error>[src]
Invoke the exists action.