Module ffsend_api::action::info [−][src]
Structs
| Info |
An action to fetch info of a shared file. |
| InfoData |
The info data object. This object is currently empty, as no additional data is sent to the server. |
| InfoResponse |
The file info response. |
Enums
| Error | |
| InfoDataError | |
| InfoError | |
| PrepareError |