Enum ffsend_api::action::info::InfoDataError [−][src]
pub enum InfoDataError {
Owned(DataError),
}Variants
Owned(DataError)Some error occurred while trying to wrap the info data in an owned object, which is required for authentication on the server. The wrapped error further described the problem.