Enum ffsend_api::action::info::InfoError[][src]

pub enum InfoError {
    Request,
    Response(ResponseError),
    Decode(ReqwestError),
}

Variants

Sending the request to fetch the file info failed.

The server responded with an error while fetching the file info.

Failed to decode the info response from the server. Maybe the server responded with data from a newer API version.