Struct ffsend_api::action::info::Info [−][src]
pub struct Info<'a> { /* fields omitted */ }An action to fetch info of a shared file.
Methods
impl<'a> Info<'a>[src]
impl<'a> Info<'a>pub fn new(file: &'a RemoteFile, nonce: Option<Vec<u8>>) -> Self[src]
pub fn new(file: &'a RemoteFile, nonce: Option<Vec<u8>>) -> SelfConstruct a new info action for the given remote file.
pub fn invoke(self, client: &Client) -> Result<InfoResponse, Error>[src]
pub fn invoke(self, client: &Client) -> Result<InfoResponse, Error>Invoke the info action.