Struct ffsend_api::action::info::Info[][src]

pub struct Info<'a> { /* fields omitted */ }

An action to fetch info of a shared file.

Methods

impl<'a> Info<'a>
[src]

Construct a new info action for the given remote file.

Invoke the info action.