Struct ffsend_api::action::info::InfoResponse [] [src]

pub struct InfoResponse { /* fields omitted */ }

The file info response.

Methods

impl InfoResponse
[src]

[src]

Get the number of times this file has been downloaded.

[src]

Get the maximum number of times the file may be downloaded.

[src]

Get the number of times this file may still be downloaded.

[src]

Get the time to live for this file, in milliseconds from the time the request was made.