Struct ffsend_api::action::info::InfoResponse
[−]
[src]
pub struct InfoResponse { /* fields omitted */ }The file info response.
Methods
impl InfoResponse[src]
pub fn download_count(&self) -> usize[src]
Get the number of times this file has been downloaded.
pub fn download_limit(&self) -> usize[src]
Get the maximum number of times the file may be downloaded.
pub fn download_left(&self) -> usize[src]
Get the number of times this file may still be downloaded.
pub fn ttl_millis(&self) -> u64[src]
Get the time to live for this file, in milliseconds from the time the request was made.