Module ffsend_api::action::metadata
[−]
[src]
Structs
| Metadata |
An action to fetch file metadata. |
| MetadataResponse |
The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action. |
| RawMetadataResponse |
The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted. |
Enums
| Error | |
| MetaError | |
| RequestError |