[−][src]Enum ffsend_api::action::metadata::MetaError
Variants
ComputeSignatureAn error occurred while computing the cryptographic signature used for decryption.
NonceRequestSending the request to gather the metadata encryption nonce failed.
NonceResponse(ResponseError)The server responded with an error while fetching the metadata encryption nonce.
Nonce(NonceError)Couldn't parse the metadata encryption nonce.
MalformedThe received metadata is malformed, and couldn't be decoded or interpreted.
DecryptFailed to decrypt the received metadata.