Enum ffsend_api::action::metadata::MetaError
source · pub enum MetaError {
ComputeSignature,
NonceRequest,
NonceResponse(ResponseError),
Nonce(NonceError),
Malformed,
Decrypt,
}Variants
ComputeSignature
An error occurred while computing the cryptographic signature used for decryption.
NonceRequest
Sending the request to gather the metadata encryption nonce failed.
NonceResponse(ResponseError)
The server responded with an error while fetching the metadata encryption nonce.
Nonce(NonceError)
Couldn’t parse the metadata encryption nonce.
Malformed
The received metadata is malformed, and couldn’t be decoded or interpreted.
Decrypt
Failed to decrypt the received metadata.