Enum ffsend_api::action::metadata::MetaError[][src]

pub enum MetaError {
    ComputeSignature,
    NonceRequest,
    NonceResponse(ResponseError),
    Nonce(NonceError),
    Malformed,
    Decrypt,
}

Variants

An error occurred while computing the cryptographic signature used for decryption.

Sending the request to gather the metadata encryption nonce failed.

The server responded with an error while fetching the metadata encryption nonce.

Couldn't parse the metadata encryption nonce.

The received metadata is malformed, and couldn't be decoded or interpreted.

Failed to decrypt the received metadata.