Struct ffsend_api::action::metadata::MetadataResponse
source · pub struct MetadataResponse { /* private fields */ }Expand description
The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.
Implementations
sourceimpl<'a> MetadataResponse
impl<'a> MetadataResponse
sourcepub fn new(metadata: MetadataData, size: u64, nonce: Vec<u8>) -> Self
pub fn new(metadata: MetadataData, size: u64, nonce: Vec<u8>) -> Self
Construct a new response with the given metadata and nonce.
pub fn from(
raw: &RawMetadataResponse,
key_set: &KeySet,
nonce: Vec<u8>
) -> Result<Self, FailureError>
sourcepub fn metadata(&self) -> &MetadataData
pub fn metadata(&self) -> &MetadataData
Get the metadata.