Struct ffsend_api::action::metadata::MetadataResponse [−][src]
pub struct MetadataResponse { /* fields omitted */ }The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.
Methods
impl<'a> MetadataResponse[src]
impl<'a> MetadataResponsepub fn new(metadata: MetadataData, size: u64, nonce: Vec<u8>) -> Self[src]
pub fn new(metadata: MetadataData, size: u64, nonce: Vec<u8>) -> SelfConstruct a new response with the given metadata and nonce.
pub fn from(
raw: &RawMetadataResponse,
key_set: &KeySet,
nonce: Vec<u8>
) -> Result<Self, FailureError>[src]
pub fn from(
raw: &RawMetadataResponse,
key_set: &KeySet,
nonce: Vec<u8>
) -> Result<Self, FailureError>pub fn metadata(&self) -> &MetadataData[src]
pub fn metadata(&self) -> &MetadataDataGet the metadata.
pub fn size(&self) -> u64[src]
pub fn size(&self) -> u64Get the file size in bytes.
pub fn nonce(&self) -> &Vec<u8>[src]
pub fn nonce(&self) -> &Vec<u8>Get the nonce.