Struct ffsend_api::action::metadata::MetadataResponse [] [src]

pub struct MetadataResponse { /* fields omitted */ }

The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.

Methods

impl<'a> MetadataResponse
[src]

[src]

Construct a new response with the given metadata and nonce.

[src]

[src]

Get the metadata.

[src]

Get the file size in bytes.

Important traits for Vec<u8>
[src]

Get the nonce.