Struct ffsend_api::action::metadata::MetadataResponse
[−]
[src]
pub struct MetadataResponse { /* fields omitted */ }The decoded and decrypted metadata response, holding all the properties. This response object is returned from this action.
Methods
impl<'a> MetadataResponse[src]
pub fn new(metadata: MetadataData, size: u64, nonce: Vec<u8>) -> Self[src]
Construct a new response with the given metadata and nonce.
pub fn from(
raw: &RawMetadataResponse,
key_set: &KeySet,
nonce: Vec<u8>
) -> Result<Self, FailureError>[src]
raw: &RawMetadataResponse,
key_set: &KeySet,
nonce: Vec<u8>
) -> Result<Self, FailureError>
pub fn metadata(&self) -> &MetadataData[src]
Get the metadata.
pub fn size(&self) -> u64[src]
Get the file size in bytes.
pub fn nonce(&self) -> &Vec<u8>[src]
Get the nonce.