Struct ffsend_api::action::metadata::RawMetadataResponse
source · pub struct RawMetadataResponse { /* private fields */ }Expand description
The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted.
Implementations
sourceimpl RawMetadataResponse
impl RawMetadataResponse
sourcepub fn decrypt_metadata(
&self,
key_set: &KeySet
) -> Result<MetadataData, FailureError>
pub fn decrypt_metadata(
&self,
key_set: &KeySet
) -> Result<MetadataData, FailureError>
Get and decrypt the metadata, based on the raw data in this response.
The decrypted data is verified using an included tag. If verification failed, an error is returned.