Struct ffsend_api::action::metadata::RawMetadataResponse
[−]
[src]
pub struct RawMetadataResponse { /* fields omitted */ }The metadata response from the server, when fetching the data through the API. This response contains raw metadata, which is still encrypted.
Methods
impl RawMetadataResponse[src]
pub fn decrypt_metadata(
&self,
key_set: &KeySet
) -> Result<MetadataData, FailureError>[src]
&self,
key_set: &KeySet
) -> Result<MetadataData, FailureError>
Get and decrypt the metadata, based on the raw data in this response.
The decrypted data is verified using an included tag. If verification failed, an error is returned.
pub fn size(&self) -> u64[src]
Get the file size in bytes.