Module ffsend_api::action::params
source · Structs
An action to set parameters for a shared file.
The parameters data object, that is sent to the server.
Builder for
ParamsData.Enums
Constants
The default download count.
The maximum (inclusive) allowed number of downloads,
enforced by the server.
The minimum allowed number of downloads, enforced by the server.