Module ffsend_api::action::params [−][src]
Structs
| Params |
An action to set parameters for a shared file. |
| ParamsData |
The parameters data object, that is sent to the server. |
| ParamsDataBuilder |
Builder for |
Enums
| ChangeError | |
| Error | |
| ParamsDataError | |
| PrepareError |
Constants
| PARAMS_DEFAULT_DOWNLOAD |
The default download count. |
| PARAMS_DEFAULT_DOWNLOAD_STR | |
| PARAMS_DOWNLOAD_MAX |
The maximum (inclusive) allowed number of downloads, enforced by the server. |
| PARAMS_DOWNLOAD_MIN |
The minimum allowed number of downloads, enforced by the server. |