Struct ffsend_api::action::params::Params [] [src]

pub struct Params<'a> { /* fields omitted */ }

An action to set parameters for a shared file.

Methods

impl<'a> Params<'a>
[src]

[src]

Construct a new parameters action for the given remote file.

[src]

Invoke the parameters action.