Struct ffsend_api::action::params::ParamsData[][src]

pub struct ParamsData { /* fields omitted */ }

The parameters data object, that is sent to the server.

Methods

impl ParamsData
[src]

Construct a new parameters object, that is empty.

Create a new parameters data object, with the given parameters.

Set the maximum number of allowed downloads, after which the file will be removed.

None may be given, to keep this parameter as is.

An error may be returned if the download value is out of the allowed bound. These bounds are fixed and enforced by the server. See PARAMS_DOWNLOAD_MIN and PARAMS_DOWNLOAD_MAX.

Check whether this parameters object is empty, and wouldn't change any parameter on the server when sent. Sending an empty parameter data object would thus be useless.