Enum ffsend_api::action::password::Error [] [src]

pub enum Error {
    Prepare(PrepareError),
    Expired,
    Change(ChangeError),
}

Variants

An error occurred while preparing the action.

The given Send file has expired, or did never exist in the first place. Therefore the file could not be downloaded.

An error has occurred while sending the password change request to the server.