Enum ffsend_api::action::password::PrepareError [−][src]
pub enum PrepareError {
Auth(NonceError),
Data(DataError),
}Variants
Auth(NonceError)Failed authenticating, needed to set a new password.
Data(DataError)Some error occurred while building the data that will be sent. The owner token might possibly be missing, the wrapped error will describe this further.