Struct ffsend_api::action::password::Password [−][src]
pub struct Password<'a> { /* fields omitted */ }An action to change a password of an uploaded Send file.
Methods
impl<'a> Password<'a>[src]
impl<'a> Password<'a>pub fn new(
file: &'a RemoteFile,
password: &'a str,
nonce: Option<Vec<u8>>
) -> Self[src]
pub fn new(
file: &'a RemoteFile,
password: &'a str,
nonce: Option<Vec<u8>>
) -> SelfConstruct a new password action for the given remote file.
pub fn invoke(self, client: &Client) -> Result<(), Error>[src]
pub fn invoke(self, client: &Client) -> Result<(), Error>Invoke the password action.