Struct ffsend_api::action::password::Password
[−]
[src]
pub struct Password<'a> { /* fields omitted */ }An action to change a password of an uploaded Send file.
Methods
impl<'a> Password<'a>[src]
pub fn new(
file: &'a RemoteFile,
password: &'a str,
nonce: Option<Vec<u8>>
) -> Self[src]
file: &'a RemoteFile,
password: &'a str,
nonce: Option<Vec<u8>>
) -> Self
Construct a new password action for the given remote file.
pub fn invoke(self, client: &Client) -> Result<(), Error>[src]
Invoke the password action.