[−][src]Enum ffsend_api::action::upload::Error
Variants
Prepare(PrepareError)An error occurred while preparing a file for uploading.
File(FileError)An error occurred while opening, reading or using the file that the should be uploaded.
Upload(UploadError)An error occurred while uploading the file.
Params(ParamsError)An error occurred while chaining file parameters.
Password(PasswordError)An error occurred while setting the password.