Enum ffsend_api::action::upload::Error[][src]

pub enum Error {
    Prepare(PrepareError),
    File(FileError),
    Upload(UploadError),
    Params(ParamsError),
    Password(PasswordError),
}

Variants

An error occurred while preparing a file for uploading.

An error occurred while opening, reading or using the file that the should be uploaded.

An error occurred while uploading the file.

An error occurred while chaining file parameters.

An error occurred while setting the password.