Enum ffsend_api::action::upload::FileError [−][src]
pub enum FileError {
NotAFile,
Open(IoError),
}Variants
NotAFileThe given path, is not not a file or doesn't exist.
Open(IoError)Failed to open the file that must be uploaded for reading.