[−][src]Enum ffsend_api::action::upload::PrepareError
Variants
Failed to prepare the file metadata for uploading.
Reader(ReaderError)Failed to create an encrypted file reader, that encrypts the file on the fly when it is read.
Failed to create a client for uploading a file.