Enum ffsend_api::action::upload::PrepareError [−][src]
pub enum PrepareError {
Meta(MetaError),
Reader(ReaderError),
}Variants
Meta(MetaError)Failed to prepare the file metadata for uploading.
Reader(ReaderError)Failed to create an encrypted file reader, that encrypts the file on the fly when it is read.