Enum ffsend_api::action::upload::UploadError[][src]

pub enum UploadError {
    Progress,
    Request,
    Response(ResponseError),
    Decode(ReqwestError),
    ParseUrl(UrlParseError),
}

Variants

Failed to start or update the uploading progress, because of this the upload can't continue.

Sending the request to upload the file failed.

The server responded with an error while uploading.

Failed to decode the upload response from the server. Maybe the server responded with data from a newer API version.

Failed to parse the retrieved URL from the upload response.