Enum ffsend_api::action::upload::UploadError [−][src]
pub enum UploadError {
Progress,
Request,
Response(ResponseError),
Decode(ReqwestError),
ParseUrl(UrlParseError),
}Variants
ProgressFailed to start or update the uploading progress, because of this the upload can't continue.
RequestSending the request to upload the file failed.
Response(ResponseError)The server responded with an error while uploading.
Decode(ReqwestError)Failed to decode the upload response from the server. Maybe the server responded with data from a newer API version.
ParseUrl(UrlParseError)Failed to parse the retrieved URL from the upload response.