[−][src]Enum ffsend_api::action::version::Error
Variants
Sending the request to check whether the file exists failed.
The server was not able to respond with any version identifiable information, the server version is unknown.
Unsupported(String)The server responded with the given version string that is currently not supported and is unknown. This might be the result of a missing compiler feature for a given Firefox Send version.