Struct ffsend_api::crypto::key_set::KeySet [] [src]

pub struct KeySet { /* fields omitted */ }

Methods

impl KeySet
[src]

[src]

Construct a new key, with the given secret and iv.

[src]

Create a key set from the given file ID and secret. This method may be used to create a key set based on a share URL.

[src]

Generate a secure new key.

If derive is true, file, authentication and metadata keys will be derived from the generated secret.

[src]

Derive a file, authentication and metadata key.

[src]

Derive an authentication key, with the given password and file URL. This method does not derive a (new) file and metadata key.

Important traits for &'a mut [u8]
[src]

Get the secret key.

[src]

Get the secret key as URL-safe base64 encoded string.

Important traits for &'a mut [u8]
[src]

Get the input vector.

[src]

Set the input vector.

[src]

Get the file encryption key, if derived.

[src]

Get the authentication encryption key, if derived.

[src]

Get the authentication encryption key, if derived, as URL-safe base64 encoded string.

[src]

Get the metadata encryption key, if derived.

[src]

Get the cipher type to use in combination with these keys.