Module ffsend_api::crypto::sig [−][src]
Functions
| signature |
Compute the signature for the given data and key. This is done using an HMAC key using the SHA256 digest. |
| signature_encoded |
Compute the signature for the given data and key. This is done using an HMAC key using the SHA256 digest. |